@@ -449,15 +449,6 @@ get_meta <- function(x){
   }
 }
 
-list0tochar <- function(x){
-  if (class(x) == 'list') {
-    tmp <- vapply(x, length, numeric(1))
-    if (sum(tmp) == 0) NA else x
-  } else {
-    x
-  }
-}
-
 parse_results <- function(x, y){
   if (!is.null(y)) {
     if ('endOfRecords' %in% names(x)) {
@@ -528,9 +519,10 @@ convmany <- function(x) {
 }
 
 check_vals <- function(x, y){
-  if (is.na(x) || is.null(x)) stop(sprintf("%s can not be NA or NULL", y),
-                                   call. = FALSE)
-  if (length(x) > 1) stop(sprintf("%s has to be length 1", y), call. = FALSE)
+  if (is.na(x) || is.null(x))
+    stop(sprintf("%s can not be NA or NULL", y), call. = FALSE)
+  if (length(x) > 1)
+    stop(sprintf("%s has to be length 1", y), call. = FALSE)
 }
 
 check_for_a_pkg <- function(x) {
@@ -685,3 +677,22 @@ setdfrbind <- function(x) {
   (data.table::setDF(
     data.table::rbindlist(x, use.names = TRUE, fill = TRUE)))
 }
+
+asl <- function(z) {
+  if (is.null(z)) return(z)
+  if (
+    is.logical(z) || tolower(z) == "true" || tolower(z) == "false"
+  ) {
+    if (z) {
+      return("true")
+    } else {
+      return("false")
+    }
+  } else {
+    return(z)
+  }
+}
+
+last <- function(x) x[length(x)]
+
+mssg <- function(v, ...) if (v) message(...)
